@@ -28,9 +28,8 @@ stream.setFormatter(formatter)
 LOG.addHandler(stream)
 
 ECB_BASE_URL = "https://www.ecb.europa.eu"
-ECB_TWO_EURO_URL = (
-    "https://www.ecb.europa.eu/euro/coins/comm/html/comm_{year}.{lang}.html"
-)
+ECB_TWO_EURO_URL = "https://www.ecb.europa.eu/euro/coins/comm/html"
+ECB_TWO_EURO_HTML_URL = ECB_TWO_EURO_URL + "/comm_{year}.{lang}.html"
 START_YEAR = 2004
 CURRENT_YEAR = datetime.datetime.now().year
 
@@ -281,12 +280,19 @@ def _parse_image_urls(coin_box: Any) -> list[str]:
     images = image_container.find_all("img")
 
     return [
-        ECB_BASE_URL + image["src"].removeprefix(".")
+        _create_image_absolute_url(image["src"].removeprefix("."))
         for image in images
         if not image["src"].endswith(".html") and image["src"]
     ]
 
 
+def _create_image_absolute_url(url: str) -> str:
+    if url.startswith("/"):
+        return ECB_BASE_URL + url
+
+    return f"{ECB_TWO_EURO_URL}/{url}"
+
+
 def _parse_circulation_date(
     box_content: Content, language: str, year: int, paragraph_index: int
 ) -> tuple[Optional[datetime.date], Optional[str]]:
@@ -490,8 +496,15 @@ def get_two_euro_commemorative_coins(
     Returns:
         List[TwoEuro]: Scraped two euro commemorative coins.
     """
-    url = ECB_TWO_EURO_URL.format(year=year, lang=lang)
+    url = ECB_TWO_EURO_HTML_URL.format(year=year, lang=lang)
     response = requests.get(url)
+    if response.status_code == 404:
+        LOG.info(
+            f"It looks like there are no coins for year: '{year}' and "
+            + f"language: '{lang}' yet."
+        )
+        return []
+
     if not response.status_code == 200:
         LOG.warning(
             f"The request to: '{url}' returned with an incorrect status code "
@@ -499,3 +512,10 @@ def get_two_euro_commemorative_coins(
         )
         return []
     return _get_two_euro_commemorative_coins(response.content, lang, year)
+
+
+if __name__ == "__main__":
+    import pprint
+
+    coins = get_two_euro_commemorative_coins(year=2012)
+    pprint.pprint(coins)
